@@ -9,15 +9,23 @@ sys.path.append(os.path.abspath('.'))
 
 extensions = ["sphinx.ext.pngmath", "sphinx.ext.extlinks", "fityk_ext"]
 
-exclude_trees = ['html', 'latex', '.svn']
-exclude_patterns = ['index.rst', 'screens.rst']
+exclude_patterns = ['html', 'latex']
+if not os.getenv('BUILD_WEBSITE'):
+    exclude_patterns += ['index.rst', 'screens.rst']
+
+if os.getenv('READTHEDOCS'):
+    # RTD works better with index.html
+    html_additional_pages = { 'index': '_build/html/fityk-manual.html' }
+    # RTD has own layout.html. This hack is needed to use all layout.html files.
+    template_bridge = "fityk_ext.MyTemplateLoader"
+
 templates_path = ['.']
 source_suffix = '.rst'
 source_encoding = 'utf-8'
 master_doc = 'fityk-manual'
 project = 'Fityk'
-copyright = '2001-2011, Fityk Developers'
-version = '0.9.8'
+copyright = '2001-2012, Fityk Developers'
+version = '1.2.1'
 release = version
 default_role = None
 
@@ -32,7 +40,7 @@ html_sidebars = {'index': [],
 html_title = 'Fityk %s manual' % version
 html_short_title = 'Manual'
 html_favicon = 'fityk.ico'
-html_static_path = ['fityk-banner.png', 'fityk.css']
+html_static_path = ['fityk-banner.png', 'fityk.css', 'img/mouse16.png']
 html_style = 'fityk.css'
 html_last_updated_fmt = '%Y-%m-%d'
 html_use_smartypants = True
@@ -91,7 +99,7 @@ latex_elements = {
 """
 }
 
-latex_show_pagerefs = True
+#latex_show_pagerefs = True
 latex_show_urls = True
 
 # determine vertical alignment of the math PNGs
