@@ -13,29 +13,23 @@ class GaussianFitter(Fityk):
         print "Data info:", self.get_info("data", 0)
 
     def run(self):
-        self.execute("guess %g = Gaussian")
+        self.execute("guess Gaussian")
+        gauss = self.all_functions()[-1] # the last function (just created)
+        print "initial Gaussian center: %g" % gauss.get_param_value("center")
         print "Fitting %s ..." % self.filename
         self.execute("fit")
         print "WSSR=", self.get_wssr()
-        print "Gaussian center: %.5g" % self.calculate_expr("%g.center")
+        print "Gaussian center: %g" % gauss.get_param_value("center")
 
     def save_session(self, filename):
         self.execute("info state >'%s'" % filename)
 
 f = Fityk()
-print f.get_info("version", True)
+print f.get_info("version")
 print "ln(2) =", f.calculate_expr("ln(2)")
 del f
 
-g = GaussianFitter("nacl01.dat")
+g = GaussianFitter(os.path.join(os.path.dirname(sys.argv[0]), "nacl01.dat"))
 g.run()
 g.save_session("tmp_save.fit")
 
-# output from commands can be handled by callback function in Python
-def show_msg(s):
-    print "output:", s
-g.py_set_show_message(show_msg)
-
-# or it can be redirected to file
-g.redir_messages(sys.stderr)
-
